# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.bridge import (
    Region,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class DataSourceOrigin(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_ORIGIN = "unknown_origin"
    SCALEWAY = "scaleway"
    EXTERNAL = "external"

    def __str__(self) -> str:
        return str(self.value)


class DataSourceType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_TYPE = "unknown_type"
    METRICS = "metrics"
    LOGS = "logs"
    TRACES = "traces"

    def __str__(self) -> str:
        return str(self.value)


class GrafanaUserRole(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_ROLE = "unknown_role"
    EDITOR = "editor"
    VIEWER = "viewer"

    def __str__(self) -> str:
        return str(self.value)


class ListDataSourcesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    TYPE_ASC = "type_asc"
    TYPE_DESC = "type_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListGrafanaUsersRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    LOGIN_ASC = "login_asc"
    LOGIN_DESC = "login_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListManagedAlertsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    TYPE_ASC = "type_asc"
    TYPE_DESC = "type_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPlansRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListTokensRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class PlanName(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_NAME = "unknown_name"
    FREE = "free"
    PREMIUM = "premium"
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)


class TokenScope(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_SCOPE = "unknown_scope"
    READ_ONLY_METRICS = "read_only_metrics"
    WRITE_ONLY_METRICS = "write_only_metrics"
    FULL_ACCESS_METRICS_RULES = "full_access_metrics_rules"
    READ_ONLY_LOGS = "read_only_logs"
    WRITE_ONLY_LOGS = "write_only_logs"
    FULL_ACCESS_LOGS_RULES = "full_access_logs_rules"
    FULL_ACCESS_ALERT_MANAGER = "full_access_alert_manager"
    READ_ONLY_TRACES = "read_only_traces"
    WRITE_ONLY_TRACES = "write_only_traces"

    def __str__(self) -> str:
        return str(self.value)


class UsageUnit(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_UNIT = "unknown_unit"
    BYTES = "bytes"
    SAMPLES = "samples"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class ContactPointEmail:
    to: str


@dataclass
class ContactPoint:
    """
    Contact point.
    """

    region: Region
    """
    Region to target. If none is passed will use default region from the config.
    """

    email: Optional[ContactPointEmail]


@dataclass
class DataSource:
    """
    Data source.
    """

    id: str
    """
    ID of the data source.
    """

    project_id: str
    """
    ID of the Project the data source belongs to.
    """

    name: str
    """
    Data source name.
    """

    url: str
    """
    Data source URL.
    """

    type_: DataSourceType
    """
    Data source type.
    """

    origin: DataSourceOrigin
    """
    Data source origin.
    """

    synchronized_with_grafana: bool
    """
    Indicates whether the data source is synchronized with Grafana.
    """

    region: Region
    """
    Region of the data source.
    """

    created_at: Optional[datetime]
    """
    Date the data source was created.
    """

    updated_at: Optional[datetime]
    """
    Date the data source was last updated.
    """


@dataclass
class GrafanaProductDashboard:
    """
    Grafana dashboard.
    """

    name: str
    """
    Dashboard name.
    """

    title: str
    """
    Dashboard title.
    """

    url: str
    """
    Dashboard URL.
    """

    tags: List[str]
    """
    Dashboard tags.
    """

    variables: List[str]
    """
    Dashboard variables.
    """


@dataclass
class GrafanaUser:
    """
    Grafana user.
    """

    id: int
    """
    ID of the Grafana user.
    """

    login: str
    """
    Username of the Grafana user.
    """

    role: GrafanaUserRole
    """
    Role assigned to the Grafana user.
    """

    password: Optional[str]
    """
    Grafana user's password.
    """


@dataclass
class Alert:
    product_family: str

    product: str

    name: str

    rule: str

    description: str


@dataclass
class Plan:
    """
    Type of pricing plan.
    """

    name: PlanName
    """
    Name of a given pricing plan.
    """

    sample_ingestion_price: int
    """
    Ingestion price in cents for 1 million samples.
    """

    logs_ingestion_price: int
    """
    Ingestion price in cents for 1 GB of logs.
    """

    traces_ingestion_price: int
    """
    Ingestion price in cents for 1 GB of traces.
    """

    monthly_price: int
    """
    Retention price in euros per month.
    """

    retention_metrics_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your metrics.
    """

    retention_logs_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your logs.
    """

    retention_traces_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your traces.
    """


@dataclass
class Token:
    """
    Token.
    """

    id: str
    """
    ID of the token.
    """

    project_id: str
    """
    ID of the Project the token belongs to.
    """

    name: str
    """
    Name of the token.
    """

    scopes: List[TokenScope]
    """
    Token permission scopes.
    """

    region: Region
    """
    Regions where the token is located.
    """

    created_at: Optional[datetime]
    """
    Token creation date.
    """

    updated_at: Optional[datetime]
    """
    Token last modification date.
    """

    secret_key: Optional[str]
    """
    Token secret key.
    """


@dataclass
class Usage:
    """
    Data source usage.
    """

    project_id: str
    """
    ID of the Project the data source belongs to.
    """

    data_source_origin: DataSourceOrigin
    """
    Origin of the data source.
    """

    data_source_type: DataSourceType
    """
    Type of the data source.
    """

    unit: UsageUnit
    """
    Unit of the data source usage.
    """

    quantity_over_interval: int
    """
    Data source usage for the given interval.
    """

    region: Region
    """
    Region of the data source usage.
    """

    data_source_id: Optional[str]
    """
    ID of the data source.
    """

    interval: Optional[str]
    """
    Interval for the data source usage.
    """


@dataclass
class AlertManager:
    """
    Alert manager information.
    """

    alert_manager_enabled: bool
    """
    The Alert manager is enabled.
    """

    managed_alerts_enabled: bool
    """
    Managed alerts are enabled.
    """

    region: Region
    """
    Regions where the Alert manager is enabled.
    """

    alert_manager_url: Optional[str]
    """
    Alert manager URL.
    """


@dataclass
class GlobalApiCreateGrafanaUserRequest:
    """
    Create a Grafana user.
    """

    login: str
    """
    Username of the Grafana user. Note that the `admin` username is not available for creation.
    """

    project_id: Optional[str]
    """
    ID of the Project in which to create the Grafana user.
    """

    role: Optional[GrafanaUserRole]
    """
    Role assigned to the Grafana user.
    """


@dataclass
class GlobalApiDeleteGrafanaUserRequest:
    """
    Delete a Grafana user.
    """

    project_id: Optional[str]
    """
    ID of the Project to target.
    """

    grafana_user_id: int
    """
    ID of the Grafana user.
    """


@dataclass
class GlobalApiGetCurrentPlanRequest:
    """
    Retrieve a pricing plan for the given Project.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class GlobalApiGetGrafanaProductDashboardRequest:
    """
    Retrieve a specific dashboard.
    """

    project_id: Optional[str]
    """
    ID of the Project the dashboard belongs to.
    """

    dashboard_name: str
    """
    Name of the dashboard.
    """


@dataclass
class GlobalApiGetGrafanaRequest:
    """
    Request a Grafana.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class GlobalApiListGrafanaProductDashboardsRequest:
    """
    Retrieve a list of available product dashboards.
    """

    project_id: Optional[str]
    """
    ID of the Project to target.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    tags: Optional[List[str]]
    """
    Tags to filter for.
    """


@dataclass
class GlobalApiListGrafanaUsersRequest:
    """
    List all Grafana users.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListGrafanaUsersRequestOrderBy]
    """
    Order of the Grafana users.
    """

    project_id: Optional[str]
    """
    ID of the Project to target.
    """


@dataclass
class GlobalApiListPlansRequest:
    """
    Retrieve a list of available pricing plans.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListPlansRequestOrderBy]


@dataclass
class GlobalApiResetGrafanaUserPasswordRequest:
    """
    Reset a Grafana user's password.
    """

    project_id: Optional[str]
    """
    ID of the Project to target.
    """

    grafana_user_id: int
    """
    ID of the Grafana user.
    """


@dataclass
class GlobalApiSelectPlanRequest:
    """
    Select a specific pricing plan.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    plan_name: Optional[PlanName]
    """
    Name of the pricing plan.
    """


@dataclass
class GlobalApiSyncGrafanaDataSourcesRequest:
    """
    Trigger the synchronization of all data sources created in the relevant regions.
    """

    project_id: Optional[str]
    """
    ID of the Project to target.
    """


@dataclass
class Grafana:
    """
    Grafana user.
    """

    grafana_url: str
    """
    URL to access your Cockpit's Grafana.
    """


@dataclass
class ListContactPointsResponse:
    """
    Response returned when listing contact points.
    """

    total_count: int
    """
    Total count of contact points associated with the default receiver.
    """

    contact_points: List[ContactPoint]
    """
    List of contact points associated with the default receiver.
    """

    has_additional_receivers: bool
    """
    Indicates whether the Alert manager has other receivers than the default one.
    """

    has_additional_contact_points: bool
    """
    Indicates whether there are unmanaged contact points on the default receiver.
    """


@dataclass
class ListDataSourcesResponse:
    """
    Response returned when listing data sources.
    """

    total_count: int
    """
    Total count of data sources matching the request.
    """

    data_sources: List[DataSource]
    """
    Data sources matching the request within the pagination.
    """


@dataclass
class ListGrafanaProductDashboardsResponse:
    """
    Output returned when listing dashboards.
    """

    total_count: int
    """
    Total count of Grafana dashboards.
    """

    dashboards: List[GrafanaProductDashboard]
    """
    Grafana dashboards information.
    """


@dataclass
class ListGrafanaUsersResponse:
    """
    Ouptut returned when listing Grafana users.
    """

    total_count: int
    """
    Total count of Grafana users.
    """

    grafana_users: List[GrafanaUser]
    """
    Grafana users information.
    """


@dataclass
class ListManagedAlertsResponse:
    """
    Response returned when listing data sources.
    """

    total_count: int
    """
    Total count of data sources matching the request.
    """

    alerts: List[Alert]
    """
    Alerts matching the request within the pagination.
    """


@dataclass
class ListPlansResponse:
    """
    Output returned when listing pricing plans.
    """

    total_count: int
    """
    Total count of available pricing plans.
    """

    plans: List[Plan]
    """
    Plan types information.
    """


@dataclass
class ListTokensResponse:
    """
    Response returned when listing tokens.
    """

    total_count: int
    """
    Total count of tokens matching the request.
    """

    tokens: List[Token]
    """
    Tokens matching the request within the pagination.
    """


@dataclass
class RegionalApiCreateContactPointRequest:
    """
    Create a contact point.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project to create the contact point in.
    """

    email: Optional[ContactPointEmail]


@dataclass
class RegionalApiCreateDataSourceRequest:
    """
    Create a data source.
    """

    name: str
    """
    Data source name.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project the data source belongs to.
    """

    type_: Optional[DataSourceType]
    """
    Data source type.
    """


@dataclass
class RegionalApiCreateTokenRequest:
    """
    Create a token.
    """

    name: str
    """
    Name of the token.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project the token belongs to.
    """

    token_scopes: Optional[List[TokenScope]]
    """
    Token permission scopes.
    """


@dataclass
class RegionalApiDeleteContactPointRequest:
    """
    Delete a contact point.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project containing the contact point to delete.
    """

    email: Optional[ContactPointEmail]


@dataclass
class RegionalApiDeleteDataSourceRequest:
    """
    Delete a data source.
    """

    data_source_id: str
    """
    ID of the data source to delete.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class RegionalApiDeleteTokenRequest:
    """
    Delete a token.
    """

    token_id: str
    """
    ID of the token to delete.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class RegionalApiDisableAlertManagerRequest:
    """
    Disable the Alert manager.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project to disable the Alert manager in.
    """


@dataclass
class RegionalApiDisableManagedAlertsRequest:
    """
    Disable the sending of managed alerts.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class RegionalApiEnableAlertManagerRequest:
    """
    Enable the Alert manager.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project to enable the Alert manager in.
    """


@dataclass
class RegionalApiEnableManagedAlertsRequest:
    """
    Enable the sending of managed alerts.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class RegionalApiGetAlertManagerRequest:
    """
    Get the Alert manager.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    Project ID of the requested Alert manager.
    """


@dataclass
class RegionalApiGetDataSourceRequest:
    """
    Retrieve a data source.
    """

    data_source_id: str
    """
    ID of the relevant data source.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class RegionalApiGetTokenRequest:
    """
    Get a token.
    """

    token_id: str
    """
    Token ID.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class RegionalApiGetUsageOverviewRequest:
    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]

    interval: Optional[str]


@dataclass
class RegionalApiListContactPointsRequest:
    """
    List contact points.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Total count of contact points to return per page.
    """

    project_id: Optional[str]
    """
    ID of the Project containing the contact points to list.
    """


@dataclass
class RegionalApiListDataSourcesRequest:
    """
    List data sources.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of data sources to return per page.
    """

    order_by: Optional[ListDataSourcesRequestOrderBy]
    """
    Sort order for data sources in the response.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only data sources from this Project will be returned.
    """

    origin: Optional[DataSourceOrigin]
    """
    Origin to filter for, only data sources with matching origin will be returned.
    """

    types: Optional[List[DataSourceType]]
    """
    Types to filter for, only data sources with matching types will be returned.
    """


@dataclass
class RegionalApiListManagedAlertsRequest:
    """
    Enable the sending of managed alerts.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of data sources to return per page.
    """

    order_by: Optional[ListManagedAlertsRequestOrderBy]
    """
    Sort order for data sources in the response.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only data sources from this Project will be returned.
    """


@dataclass
class RegionalApiListTokensRequest:
    """
    List tokens.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of tokens to return per page.
    """

    order_by: Optional[ListTokensRequestOrderBy]
    """
    Order in which to return results.
    """

    project_id: Optional[str]
    """
    ID of the Project the tokens belong to.
    """

    token_scopes: Optional[List[TokenScope]]
    """
    Token scopes to filter for.
    """


@dataclass
class RegionalApiTriggerTestAlertRequest:
    """
    Request to trigger a test alert.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class RegionalApiUpdateDataSourceRequest:
    """
    Update a data source name.
    """

    data_source_id: str
    """
    ID of the data source to update.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    name: Optional[str]
    """
    Updated name of the data source.
    """


@dataclass
class UsageOverview:
    scaleway_metrics_usage: Optional[Usage]

    scaleway_logs_usage: Optional[Usage]

    external_metrics_usage: Optional[Usage]

    external_logs_usage: Optional[Usage]

    external_traces_usage: Optional[Usage]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Region,
)
from scaleway_core.utils import (
    OneOfPossibility,
    resolve_one_of,
    validate_path_param,
    fetch_all_pages,
)
from .types import (
    ListIPsRequestOrderBy,
    ResourceType,
    BookIPRequest,
    IP,
    ListIPsResponse,
    ReleaseIPSetRequest,
    Reverse,
    Source,
    UpdateIPRequest,
)
from .marshalling import (
    unmarshal_IP,
    unmarshal_ListIPsResponse,
    marshal_BookIPRequest,
    marshal_ReleaseIPSetRequest,
    marshal_UpdateIPRequest,
)


class IpamV1API(API):
    """
    This API allows you to manage your Scaleway IP addresses with our IP Address Management tool.
    """

    def book_ip(
        self,
        *,
        source: Source,
        is_ipv6: bool,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        address: Optional[str] = None,
        tags: Optional[List[str]] = None,
    ) -> IP:
        """
        Book a new IP.
        Book a new IP from the specified source. Currently IPs can only be booked from a Private Network.
        :param source: Source in which to book the IP. Not all sources are available for booking.
        :param is_ipv6: Request an IPv6 instead of an IPv4.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: When creating an IP in a Private Network, the Project must match the Private Network's Project.
        :param address: The requested address should not include the subnet mask (/suffix). Note that only the Private Network source allows you to pick a specific IP. If the requested IP is already booked, then the call will fail.
        :param tags: Tags for the IP.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.book_ip(
                source=Source(),
                is_ipv6=False,
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipam/v1/regions/{param_region}/ips",
            body=marshal_BookIPRequest(
                BookIPRequest(
                    source=source,
                    is_ipv6=is_ipv6,
                    region=region,
                    project_id=project_id,
                    address=address,
                    tags=tags,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def release_ip(
        self,
        *,
        ip_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Release an IP.
        Release an IP not currently attached to a resource, and returns it to the available IP pool.
        :param ip_id: IP ID.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.release_ip(
                ip_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "DELETE",
            f"/ipam/v1/regions/{param_region}/ips/{param_ip_id}",
            body={},
        )

        self._throw_on_error(res)

    def release_ip_set(
        self,
        *,
        region: Optional[Region] = None,
        ip_ids: Optional[List[str]] = None,
    ) -> None:
        """
        :param region: Region to target. If none is passed will use default region from the config.
        :param ip_ids:

        Usage:
        ::

            result = api.release_ip_set()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipam/v1/regions/{param_region}/ip-sets/release",
            body=marshal_ReleaseIPSetRequest(
                ReleaseIPSetRequest(
                    region=region,
                    ip_ids=ip_ids,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def get_ip(
        self,
        *,
        ip_id: str,
        region: Optional[Region] = None,
    ) -> IP:
        """
        Get an IP.
        Retrieve details of an existing IP, specified by its IP ID.
        :param ip_id: IP ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.get_ip(
                ip_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "GET",
            f"/ipam/v1/regions/{param_region}/ips/{param_ip_id}",
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def update_ip(
        self,
        *,
        ip_id: str,
        region: Optional[Region] = None,
        tags: Optional[List[str]] = None,
        reverses: Optional[List[Reverse]] = None,
    ) -> IP:
        """
        Update an IP.
        Update parameters including tags of the specified IP.
        :param ip_id: IP ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param tags: Tags for the IP.
        :param reverses: Array of reverse domain names associated with an IP in the subnet of the current IP.
        :return: :class:`IP <IP>`

        Usage:
        ::

            result = api.update_ip(
                ip_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_ip_id = validate_path_param("ip_id", ip_id)

        res = self._request(
            "PATCH",
            f"/ipam/v1/regions/{param_region}/ips/{param_ip_id}",
            body=marshal_UpdateIPRequest(
                UpdateIPRequest(
                    ip_id=ip_id,
                    region=region,
                    tags=tags,
                    reverses=reverses,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_IP(res.json())

    def list_i_ps(
        self,
        *,
        region: Optional[Region] = None,
        order_by: Optional[ListIPsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        zonal: Optional[str] = None,
        private_network_id: Optional[str] = None,
        subnet_id: Optional[str] = None,
        vpc_id: Optional[str] = None,
        attached: Optional[bool] = None,
        resource_id: Optional[str] = None,
        resource_type: Optional[ResourceType] = None,
        mac_address: Optional[str] = None,
        tags: Optional[List[str]] = None,
        organization_id: Optional[str] = None,
        is_ipv6: Optional[bool] = None,
        resource_name: Optional[str] = None,
        resource_types: Optional[List[ResourceType]] = None,
    ) -> ListIPsResponse:
        """
        List existing IPs.
        List existing IPs in the specified region using various filters. For example, you can filter for IPs within a specified Private Network, or for public IPs within a specified Project. By default, the IPs returned in the list are ordered by creation date in ascending order, though this can be modified via the order_by field.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: Sort order of the returned IPs.
        :param page: Page number to return, from the paginated results.
        :param page_size: Maximum number of IPs to return per page.
        :param project_id: Project ID to filter for. Only IPs belonging to this Project will be returned.
        :param zonal: Zone to filter for. Only IPs that are zonal, and in this zone, will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param private_network_id: Only IPs that are private, and in this Private Network, will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param subnet_id: Only IPs inside this exact subnet will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param vpc_id: Only IPs owned by resources in this VPC will be returned.
        :param attached: Defines whether to filter only for IPs which are attached to a resource.
        :param resource_id: Resource ID to filter for. Only IPs attached to this resource will be returned.
        :param resource_type: Resource type to filter for. Only IPs attached to this type of resource will be returned.
        :param mac_address: MAC address to filter for. Only IPs attached to a resource with this MAC address will be returned.
        :param tags: Tags to filter for, only IPs with one or more matching tags will be returned.
        :param organization_id: Organization ID to filter for. Only IPs belonging to this Organization will be returned.
        :param is_ipv6: Defines whether to filter only for IPv4s or IPv6s.
        :param resource_name: Attached resource name to filter for, only IPs attached to a resource with this string within their name will be returned.
        :param resource_types: Resource types to filter for. Only IPs attached to these types of resources will be returned.
        :return: :class:`ListIPsResponse <ListIPsResponse>`

        Usage:
        ::

            result = api.list_i_ps()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/ipam/v1/regions/{param_region}/ips",
            params={
                "attached": attached,
                "is_ipv6": is_ipv6,
                "mac_address": mac_address,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "resource_id": resource_id,
                "resource_name": resource_name,
                "resource_type": resource_type,
                "resource_types": resource_types,
                "tags": tags,
                "vpc_id": vpc_id,
                **resolve_one_of(
                    [
                        OneOfPossibility("private_network_id", private_network_id),
                        OneOfPossibility("subnet_id", subnet_id),
                        OneOfPossibility("zonal", zonal),
                    ]
                ),
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListIPsResponse(res.json())

    def list_i_ps_all(
        self,
        *,
        region: Optional[Region] = None,
        order_by: Optional[ListIPsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        zonal: Optional[str] = None,
        private_network_id: Optional[str] = None,
        subnet_id: Optional[str] = None,
        vpc_id: Optional[str] = None,
        attached: Optional[bool] = None,
        resource_id: Optional[str] = None,
        resource_type: Optional[ResourceType] = None,
        mac_address: Optional[str] = None,
        tags: Optional[List[str]] = None,
        organization_id: Optional[str] = None,
        is_ipv6: Optional[bool] = None,
        resource_name: Optional[str] = None,
        resource_types: Optional[List[ResourceType]] = None,
    ) -> List[IP]:
        """
        List existing IPs.
        List existing IPs in the specified region using various filters. For example, you can filter for IPs within a specified Private Network, or for public IPs within a specified Project. By default, the IPs returned in the list are ordered by creation date in ascending order, though this can be modified via the order_by field.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: Sort order of the returned IPs.
        :param page: Page number to return, from the paginated results.
        :param page_size: Maximum number of IPs to return per page.
        :param project_id: Project ID to filter for. Only IPs belonging to this Project will be returned.
        :param zonal: Zone to filter for. Only IPs that are zonal, and in this zone, will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param private_network_id: Only IPs that are private, and in this Private Network, will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param subnet_id: Only IPs inside this exact subnet will be returned.
        One-Of ('source'): at most one of 'zonal', 'private_network_id', 'subnet_id' could be set.
        :param vpc_id: Only IPs owned by resources in this VPC will be returned.
        :param attached: Defines whether to filter only for IPs which are attached to a resource.
        :param resource_id: Resource ID to filter for. Only IPs attached to this resource will be returned.
        :param resource_type: Resource type to filter for. Only IPs attached to this type of resource will be returned.
        :param mac_address: MAC address to filter for. Only IPs attached to a resource with this MAC address will be returned.
        :param tags: Tags to filter for, only IPs with one or more matching tags will be returned.
        :param organization_id: Organization ID to filter for. Only IPs belonging to this Organization will be returned.
        :param is_ipv6: Defines whether to filter only for IPv4s or IPv6s.
        :param resource_name: Attached resource name to filter for, only IPs attached to a resource with this string within their name will be returned.
        :param resource_types: Resource types to filter for. Only IPs attached to these types of resources will be returned.
        :return: :class:`List[IP] <List[IP]>`

        Usage:
        ::

            result = api.list_i_ps_all()
        """

        return fetch_all_pages(
            type=ListIPsResponse,
            key="ips",
            fetcher=self.list_i_ps,
            args={
                "region": region,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "project_id": project_id,
                "vpc_id": vpc_id,
                "attached": attached,
                "resource_id": resource_id,
                "resource_type": resource_type,
                "mac_address": mac_address,
                "tags": tags,
                "organization_id": organization_id,
                "is_ipv6": is_ipv6,
                "resource_name": resource_name,
                "resource_types": resource_types,
                "zonal": zonal,
                "private_network_id": private_network_id,
                "subnet_id": subnet_id,
            },
        )



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from typing import List

from .types import (
    DeploymentStatus,
)

DEPLOYMENT_TRANSIENT_STATUSES: List[DeploymentStatus] = [
    DeploymentStatus.CREATING,
    DeploymentStatus.DEPLOYING,
    DeploymentStatus.DELETING,
]
"""
Lists transient statutes of the enum :class:`DeploymentStatus <DeploymentStatus>`.
"""



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListProjectsRequestOrderBy
from .types import Project
from .types import CreateProjectRequest
from .types import DeleteProjectRequest
from .types import GetProjectRequest
from .types import ListProjectsRequest
from .types import ListProjectsResponse
from .types import UpdateProjectRequest
from .api import AccountV2API

__all__ = [
    "ListProjectsRequestOrderBy",
    "Project",
    "CreateProjectRequest",
    "DeleteProjectRequest",
    "GetProjectRequest",
    "ListProjectsRequest",
    "ListProjectsResponse",
    "UpdateProjectRequest",
    "AccountV2API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Region,
)
from scaleway_core.utils import (
    random_name,
    validate_path_param,
    fetch_all_pages,
)
from .types import (
    ListNatsAccountsRequestOrderBy,
    ListNatsCredentialsRequestOrderBy,
    ListSnsCredentialsRequestOrderBy,
    ListSqsCredentialsRequestOrderBy,
    ListNatsAccountsResponse,
    ListNatsCredentialsResponse,
    ListSnsCredentialsResponse,
    ListSqsCredentialsResponse,
    NatsAccount,
    NatsApiCreateNatsAccountRequest,
    NatsApiCreateNatsCredentialsRequest,
    NatsApiUpdateNatsAccountRequest,
    NatsCredentials,
    SnsApiActivateSnsRequest,
    SnsApiCreateSnsCredentialsRequest,
    SnsApiDeactivateSnsRequest,
    SnsApiUpdateSnsCredentialsRequest,
    SnsCredentials,
    SnsInfo,
    SnsPermissions,
    SqsApiActivateSqsRequest,
    SqsApiCreateSqsCredentialsRequest,
    SqsApiDeactivateSqsRequest,
    SqsApiUpdateSqsCredentialsRequest,
    SqsCredentials,
    SqsInfo,
    SqsPermissions,
)
from .marshalling import (
    unmarshal_NatsAccount,
    unmarshal_NatsCredentials,
    unmarshal_SnsCredentials,
    unmarshal_SqsCredentials,
    unmarshal_ListNatsAccountsResponse,
    unmarshal_ListNatsCredentialsResponse,
    unmarshal_ListSnsCredentialsResponse,
    unmarshal_ListSqsCredentialsResponse,
    unmarshal_SnsInfo,
    unmarshal_SqsInfo,
    marshal_NatsApiCreateNatsAccountRequest,
    marshal_NatsApiCreateNatsCredentialsRequest,
    marshal_NatsApiUpdateNatsAccountRequest,
    marshal_SnsApiActivateSnsRequest,
    marshal_SnsApiCreateSnsCredentialsRequest,
    marshal_SnsApiDeactivateSnsRequest,
    marshal_SnsApiUpdateSnsCredentialsRequest,
    marshal_SqsApiActivateSqsRequest,
    marshal_SqsApiCreateSqsCredentialsRequest,
    marshal_SqsApiDeactivateSqsRequest,
    marshal_SqsApiUpdateSqsCredentialsRequest,
)


class MnqV1Beta1NatsAPI(API):
    """
    This API allows you to manage Scaleway Messaging and Queuing NATS accounts.
    """

    def create_nats_account(
        self,
        *,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        project_id: Optional[str] = None,
    ) -> NatsAccount:
        """
        Create a NATS account.
        Create a NATS account associated with a Project.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: NATS account name.
        :param project_id: Project containing the NATS account.
        :return: :class:`NatsAccount <NatsAccount>`

        Usage:
        ::

            result = api.create_nats_account()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/nats-accounts",
            body=marshal_NatsApiCreateNatsAccountRequest(
                NatsApiCreateNatsAccountRequest(
                    region=region,
                    name=name or random_name(prefix="mnq"),
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_NatsAccount(res.json())

    def delete_nats_account(
        self,
        *,
        nats_account_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete a NATS account.
        Delete a NATS account, specified by its NATS account ID. Note that deleting a NATS account is irreversible, and any credentials, streams, consumer and stored messages belonging to this NATS account will also be deleted.
        :param nats_account_id: ID of the NATS account to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_nats_account(
                nats_account_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_nats_account_id = validate_path_param("nats_account_id", nats_account_id)

        res = self._request(
            "DELETE",
            f"/mnq/v1beta1/regions/{param_region}/nats-accounts/{param_nats_account_id}",
        )

        self._throw_on_error(res)

    def update_nats_account(
        self,
        *,
        nats_account_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
    ) -> NatsAccount:
        """
        Update the name of a NATS account.
        Update the name of a NATS account, specified by its NATS account ID.
        :param nats_account_id: ID of the NATS account to update.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: NATS account name.
        :return: :class:`NatsAccount <NatsAccount>`

        Usage:
        ::

            result = api.update_nats_account(
                nats_account_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_nats_account_id = validate_path_param("nats_account_id", nats_account_id)

        res = self._request(
            "PATCH",
            f"/mnq/v1beta1/regions/{param_region}/nats-accounts/{param_nats_account_id}",
            body=marshal_NatsApiUpdateNatsAccountRequest(
                NatsApiUpdateNatsAccountRequest(
                    nats_account_id=nats_account_id,
                    region=region,
                    name=name,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_NatsAccount(res.json())

    def get_nats_account(
        self,
        *,
        nats_account_id: str,
        region: Optional[Region] = None,
    ) -> NatsAccount:
        """
        Get a NATS account.
        Retrieve information about an existing NATS account identified by its NATS account ID. Its full details, including name and endpoint, are returned in the response.
        :param nats_account_id: ID of the NATS account to get.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`NatsAccount <NatsAccount>`

        Usage:
        ::

            result = api.get_nats_account(
                nats_account_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_nats_account_id = validate_path_param("nats_account_id", nats_account_id)

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/nats-accounts/{param_nats_account_id}",
        )

        self._throw_on_error(res)
        return unmarshal_NatsAccount(res.json())

    def list_nats_accounts(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListNatsAccountsRequestOrderBy] = None,
    ) -> ListNatsAccountsResponse:
        """
        List NATS accounts.
        List all NATS accounts in the specified region, for a Scaleway Organization or Project. By default, the NATS accounts returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only NATS accounts in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of NATS accounts to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`ListNatsAccountsResponse <ListNatsAccountsResponse>`

        Usage:
        ::

            result = api.list_nats_accounts()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/nats-accounts",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListNatsAccountsResponse(res.json())

    def list_nats_accounts_all(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListNatsAccountsRequestOrderBy] = None,
    ) -> List[NatsAccount]:
        """
        List NATS accounts.
        List all NATS accounts in the specified region, for a Scaleway Organization or Project. By default, the NATS accounts returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only NATS accounts in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of NATS accounts to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`List[NatsAccount] <List[NatsAccount]>`

        Usage:
        ::

            result = api.list_nats_accounts_all()
        """

        return fetch_all_pages(
            type=ListNatsAccountsResponse,
            key="nats_accounts",
            fetcher=self.list_nats_accounts,
            args={
                "region": region,
                "project_id": project_id,
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
            },
        )

    def create_nats_credentials(
        self,
        *,
        nats_account_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
    ) -> NatsCredentials:
        """
        Create NATS credentials.
        Create a set of credentials for a NATS account, specified by its NATS account ID.
        :param nats_account_id: NATS account containing the credentials.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Name of the credentials.
        :return: :class:`NatsCredentials <NatsCredentials>`

        Usage:
        ::

            result = api.create_nats_credentials(
                nats_account_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/nats-credentials",
            body=marshal_NatsApiCreateNatsCredentialsRequest(
                NatsApiCreateNatsCredentialsRequest(
                    nats_account_id=nats_account_id,
                    region=region,
                    name=name or random_name(prefix="mnq"),
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_NatsCredentials(res.json())

    def delete_nats_credentials(
        self,
        *,
        nats_credentials_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete NATS credentials.
        Delete a set of credentials, specified by their credentials ID. Deleting credentials is irreversible and cannot be undone. The credentials can no longer be used to access the NATS account, and active connections using this credentials will be closed.
        :param nats_credentials_id: ID of the credentials to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_nats_credentials(
                nats_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_nats_credentials_id = validate_path_param(
            "nats_credentials_id", nats_credentials_id
        )

        res = self._request(
            "DELETE",
            f"/mnq/v1beta1/regions/{param_region}/nats-credentials/{param_nats_credentials_id}",
        )

        self._throw_on_error(res)

    def get_nats_credentials(
        self,
        *,
        nats_credentials_id: str,
        region: Optional[Region] = None,
    ) -> NatsCredentials:
        """
        Get NATS credentials.
        Retrieve an existing set of credentials, identified by the `nats_credentials_id`. The credentials themselves are NOT returned, only their metadata (NATS account ID, credentials name, etc), are returned in the response.
        :param nats_credentials_id: ID of the credentials to get.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`NatsCredentials <NatsCredentials>`

        Usage:
        ::

            result = api.get_nats_credentials(
                nats_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_nats_credentials_id = validate_path_param(
            "nats_credentials_id", nats_credentials_id
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/nats-credentials/{param_nats_credentials_id}",
        )

        self._throw_on_error(res)
        return unmarshal_NatsCredentials(res.json())

    def list_nats_credentials(
        self,
        *,
        region: Optional[Region] = None,
        nats_account_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListNatsCredentialsRequestOrderBy] = None,
    ) -> ListNatsCredentialsResponse:
        """
        List NATS credentials.
        List existing credentials in the specified NATS account. The response contains only the metadata for the credentials, not the credentials themselves, which are only returned after a **Create Credentials** call.
        :param region: Region to target. If none is passed will use default region from the config.
        :param nats_account_id: Include only credentials for this NATS account.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`ListNatsCredentialsResponse <ListNatsCredentialsResponse>`

        Usage:
        ::

            result = api.list_nats_credentials()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/nats-credentials",
            params={
                "nats_account_id": nats_account_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListNatsCredentialsResponse(res.json())

    def list_nats_credentials_all(
        self,
        *,
        region: Optional[Region] = None,
        nats_account_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListNatsCredentialsRequestOrderBy] = None,
    ) -> List[NatsCredentials]:
        """
        List NATS credentials.
        List existing credentials in the specified NATS account. The response contains only the metadata for the credentials, not the credentials themselves, which are only returned after a **Create Credentials** call.
        :param region: Region to target. If none is passed will use default region from the config.
        :param nats_account_id: Include only credentials for this NATS account.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`List[NatsCredentials] <List[NatsCredentials]>`

        Usage:
        ::

            result = api.list_nats_credentials_all()
        """

        return fetch_all_pages(
            type=ListNatsCredentialsResponse,
            key="nats_credentials",
            fetcher=self.list_nats_credentials,
            args={
                "region": region,
                "nats_account_id": nats_account_id,
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
            },
        )


class MnqV1Beta1SnsAPI(API):
    """
    This API allows you to manage your Scaleway Messaging and Queuing SNS brokers.
    """

    def activate_sns(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SnsInfo:
        """
        Activate SNS.
        Activate SNS for the specified Project ID. SNS must be activated before any usage. Activating SNS does not trigger any billing, and you can deactivate at any time.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project on which to activate the SNS service.
        :return: :class:`SnsInfo <SnsInfo>`

        Usage:
        ::

            result = api.activate_sns()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/activate-sns",
            body=marshal_SnsApiActivateSnsRequest(
                SnsApiActivateSnsRequest(
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SnsInfo(res.json())

    def get_sns_info(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SnsInfo:
        """
        Get SNS info.
        Retrieve the SNS information of the specified Project ID. Informations include the activation status and the SNS API endpoint URL.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project to retrieve SNS info from.
        :return: :class:`SnsInfo <SnsInfo>`

        Usage:
        ::

            result = api.get_sns_info()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sns-info",
            params={
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_SnsInfo(res.json())

    def deactivate_sns(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SnsInfo:
        """
        Deactivate SNS.
        Deactivate SNS for the specified Project ID.You must delete all topics and credentials before this call or you need to set the force_delete parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project on which to deactivate the SNS service.
        :return: :class:`SnsInfo <SnsInfo>`

        Usage:
        ::

            result = api.deactivate_sns()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/deactivate-sns",
            body=marshal_SnsApiDeactivateSnsRequest(
                SnsApiDeactivateSnsRequest(
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SnsInfo(res.json())

    def create_sns_credentials(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        permissions: Optional[SnsPermissions] = None,
    ) -> SnsCredentials:
        """
        Create SNS credentials.
        Create a set of credentials for SNS, specified by a Project ID. Credentials give the bearer access to topics, and the level of permissions can be defined granularly.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project containing the SNS credentials.
        :param name: Name of the credentials.
        :param permissions: Permissions associated with these credentials.
        :return: :class:`SnsCredentials <SnsCredentials>`

        Usage:
        ::

            result = api.create_sns_credentials()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/sns-credentials",
            body=marshal_SnsApiCreateSnsCredentialsRequest(
                SnsApiCreateSnsCredentialsRequest(
                    region=region,
                    project_id=project_id,
                    name=name or random_name(prefix="mnq_sns"),
                    permissions=permissions,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SnsCredentials(res.json())

    def delete_sns_credentials(
        self,
        *,
        sns_credentials_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete SNS credentials.
        Delete a set of SNS credentials, specified by their credentials ID. Deleting credentials is irreversible and cannot be undone. The credentials can then no longer be used to access SNS.
        :param sns_credentials_id: ID of the credentials to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_sns_credentials(
                sns_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sns_credentials_id = validate_path_param(
            "sns_credentials_id", sns_credentials_id
        )

        res = self._request(
            "DELETE",
            f"/mnq/v1beta1/regions/{param_region}/sns-credentials/{param_sns_credentials_id}",
        )

        self._throw_on_error(res)

    def update_sns_credentials(
        self,
        *,
        sns_credentials_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        permissions: Optional[SnsPermissions] = None,
    ) -> SnsCredentials:
        """
        Update SNS credentials.
        Update a set of SNS credentials. You can update the credentials' name, or their permissions.
        :param sns_credentials_id: ID of the SNS credentials to update.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Name of the credentials.
        :param permissions: Permissions associated with these credentials.
        :return: :class:`SnsCredentials <SnsCredentials>`

        Usage:
        ::

            result = api.update_sns_credentials(
                sns_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sns_credentials_id = validate_path_param(
            "sns_credentials_id", sns_credentials_id
        )

        res = self._request(
            "PATCH",
            f"/mnq/v1beta1/regions/{param_region}/sns-credentials/{param_sns_credentials_id}",
            body=marshal_SnsApiUpdateSnsCredentialsRequest(
                SnsApiUpdateSnsCredentialsRequest(
                    sns_credentials_id=sns_credentials_id,
                    region=region,
                    name=name,
                    permissions=permissions,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SnsCredentials(res.json())

    def get_sns_credentials(
        self,
        *,
        sns_credentials_id: str,
        region: Optional[Region] = None,
    ) -> SnsCredentials:
        """
        Get SNS credentials.
        Retrieve an existing set of credentials, identified by the `credentials_id`. The credentials themselves, as well as their metadata (name, project ID etc), are returned in the response.
        :param sns_credentials_id: ID of the SNS credentials to get.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`SnsCredentials <SnsCredentials>`

        Usage:
        ::

            result = api.get_sns_credentials(
                sns_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sns_credentials_id = validate_path_param(
            "sns_credentials_id", sns_credentials_id
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sns-credentials/{param_sns_credentials_id}",
        )

        self._throw_on_error(res)
        return unmarshal_SnsCredentials(res.json())

    def list_sns_credentials(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListSnsCredentialsRequestOrderBy] = None,
    ) -> ListSnsCredentialsResponse:
        """
        List SNS credentials.
        List existing SNS credentials in the specified region. The response contains only the metadata for the credentials, not the credentials themselves.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only SNS credentials in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`ListSnsCredentialsResponse <ListSnsCredentialsResponse>`

        Usage:
        ::

            result = api.list_sns_credentials()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sns-credentials",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListSnsCredentialsResponse(res.json())

    def list_sns_credentials_all(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListSnsCredentialsRequestOrderBy] = None,
    ) -> List[SnsCredentials]:
        """
        List SNS credentials.
        List existing SNS credentials in the specified region. The response contains only the metadata for the credentials, not the credentials themselves.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only SNS credentials in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`List[SnsCredentials] <List[SnsCredentials]>`

        Usage:
        ::

            result = api.list_sns_credentials_all()
        """

        return fetch_all_pages(
            type=ListSnsCredentialsResponse,
            key="sns_credentials",
            fetcher=self.list_sns_credentials,
            args={
                "region": region,
                "project_id": project_id,
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
            },
        )


class MnqV1Beta1SqsAPI(API):
    """
    This API allows you to manage your Scaleway Messaging and Queuing SQS brokers.
    """

    def activate_sqs(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SqsInfo:
        """
        Activate SQS.
        Activate SQS for the specified Project ID. SQS must be activated before any usage such as creating credentials and queues. Activating SQS does not trigger any billing, and you can deactivate at any time.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project on which to activate the SQS service.
        :return: :class:`SqsInfo <SqsInfo>`

        Usage:
        ::

            result = api.activate_sqs()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/activate-sqs",
            body=marshal_SqsApiActivateSqsRequest(
                SqsApiActivateSqsRequest(
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SqsInfo(res.json())

    def get_sqs_info(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SqsInfo:
        """
        Get SQS info.
        Retrieve the SQS information of the specified Project ID. Informations include the activation status and the SQS API endpoint URL.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project to retrieve SQS info from.
        :return: :class:`SqsInfo <SqsInfo>`

        Usage:
        ::

            result = api.get_sqs_info()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sqs-info",
            params={
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_SqsInfo(res.json())

    def deactivate_sqs(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> SqsInfo:
        """
        Deactivate SQS.
        Deactivate SQS for the specified Project ID. You must delete all queues and credentials before this call or you need to set the force_delete parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project on which to deactivate the SQS service.
        :return: :class:`SqsInfo <SqsInfo>`

        Usage:
        ::

            result = api.deactivate_sqs()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/deactivate-sqs",
            body=marshal_SqsApiDeactivateSqsRequest(
                SqsApiDeactivateSqsRequest(
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SqsInfo(res.json())

    def create_sqs_credentials(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        permissions: Optional[SqsPermissions] = None,
    ) -> SqsCredentials:
        """
        Create SQS credentials.
        Create a set of credentials for SQS, specified by a Project ID. Credentials give the bearer access to queues, and the level of permissions can be defined granularly.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project containing the SQS credentials.
        :param name: Name of the credentials.
        :param permissions: Permissions associated with these credentials.
        :return: :class:`SqsCredentials <SqsCredentials>`

        Usage:
        ::

            result = api.create_sqs_credentials()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/mnq/v1beta1/regions/{param_region}/sqs-credentials",
            body=marshal_SqsApiCreateSqsCredentialsRequest(
                SqsApiCreateSqsCredentialsRequest(
                    region=region,
                    project_id=project_id,
                    name=name or random_name(prefix="mnq_sqs"),
                    permissions=permissions,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SqsCredentials(res.json())

    def delete_sqs_credentials(
        self,
        *,
        sqs_credentials_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete SQS credentials.
        Delete a set of SQS credentials, specified by their credentials ID. Deleting credentials is irreversible and cannot be undone. The credentials can then no longer be used to access SQS.
        :param sqs_credentials_id: ID of the credentials to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_sqs_credentials(
                sqs_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sqs_credentials_id = validate_path_param(
            "sqs_credentials_id", sqs_credentials_id
        )

        res = self._request(
            "DELETE",
            f"/mnq/v1beta1/regions/{param_region}/sqs-credentials/{param_sqs_credentials_id}",
        )

        self._throw_on_error(res)

    def update_sqs_credentials(
        self,
        *,
        sqs_credentials_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        permissions: Optional[SqsPermissions] = None,
    ) -> SqsCredentials:
        """
        Update SQS credentials.
        Update a set of SQS credentials. You can update the credentials' name, or their permissions.
        :param sqs_credentials_id: ID of the SQS credentials to update.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Name of the credentials.
        :param permissions: Permissions associated with these credentials.
        :return: :class:`SqsCredentials <SqsCredentials>`

        Usage:
        ::

            result = api.update_sqs_credentials(
                sqs_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sqs_credentials_id = validate_path_param(
            "sqs_credentials_id", sqs_credentials_id
        )

        res = self._request(
            "PATCH",
            f"/mnq/v1beta1/regions/{param_region}/sqs-credentials/{param_sqs_credentials_id}",
            body=marshal_SqsApiUpdateSqsCredentialsRequest(
                SqsApiUpdateSqsCredentialsRequest(
                    sqs_credentials_id=sqs_credentials_id,
                    region=region,
                    name=name,
                    permissions=permissions,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SqsCredentials(res.json())

    def get_sqs_credentials(
        self,
        *,
        sqs_credentials_id: str,
        region: Optional[Region] = None,
    ) -> SqsCredentials:
        """
        Get SQS credentials.
        Retrieve an existing set of credentials, identified by the `credentials_id`. The credentials themselves, as well as their metadata (name, project ID etc), are returned in the response.
        :param sqs_credentials_id: ID of the SQS credentials to get.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`SqsCredentials <SqsCredentials>`

        Usage:
        ::

            result = api.get_sqs_credentials(
                sqs_credentials_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_sqs_credentials_id = validate_path_param(
            "sqs_credentials_id", sqs_credentials_id
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sqs-credentials/{param_sqs_credentials_id}",
        )

        self._throw_on_error(res)
        return unmarshal_SqsCredentials(res.json())

    def list_sqs_credentials(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListSqsCredentialsRequestOrderBy] = None,
    ) -> ListSqsCredentialsResponse:
        """
        List SQS credentials.
        List existing SQS credentials in the specified region. The response contains only the metadata for the credentials, not the credentials themselves.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only SQS credentials in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`ListSqsCredentialsResponse <ListSqsCredentialsResponse>`

        Usage:
        ::

            result = api.list_sqs_credentials()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/mnq/v1beta1/regions/{param_region}/sqs-credentials",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListSqsCredentialsResponse(res.json())

    def list_sqs_credentials_all(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListSqsCredentialsRequestOrderBy] = None,
    ) -> List[SqsCredentials]:
        """
        List SQS credentials.
        List existing SQS credentials in the specified region. The response contains only the metadata for the credentials, not the credentials themselves.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Include only SQS credentials in this Project.
        :param page: Page number to return.
        :param page_size: Maximum number of credentials to return per page.
        :param order_by: Order in which to return results.
        :return: :class:`List[SqsCredentials] <List[SqsCredentials]>`

        Usage:
        ::

            result = api.list_sqs_credentials_all()
        """

        return fetch_all_pages(
            type=ListSqsCredentialsResponse,
            key="sqs_credentials",
            fetcher=self.list_sqs_credentials,
            args={
                "region": region,
                "project_id": project_id,
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
            },
        )



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ACLRuleAction
from .types import ACLRuleDirection
from .types import ACLRuleProtocol
from .types import EngineSettingPropertyType
from .types import InstanceLogStatus
from .content import INSTANCE_LOG_TRANSIENT_STATUSES
from .types import InstanceStatus
from .content import INSTANCE_TRANSIENT_STATUSES
from .types import ListDatabasesRequestOrderBy
from .types import ListInstanceLogsRequestOrderBy
from .types import ListInstancesRequestOrderBy
from .types import ListPrivilegesRequestOrderBy
from .types import ListSnapshotsRequestOrderBy
from .types import ListUsersRequestOrderBy
from .types import MaintenanceStatus
from .content import MAINTENANCE_TRANSIENT_STATUSES
from .types import NodeTypeGeneration
from .types import NodeTypeStock
from .types import Permission
from .types import ReadReplicaStatus
from .content import READ_REPLICA_TRANSIENT_STATUSES
from .types import SnapshotStatus
from .content import SNAPSHOT_TRANSIENT_STATUSES
from .types import StorageClass
from .types import VolumeType
from .types import EndpointDirectAccessDetails
from .types import EndpointLoadBalancerDetails
from .types import EndpointPrivateNetworkDetails
from .types import EndpointSpecPrivateNetworkIpamConfig
from .types import ReadReplicaEndpointSpecPrivateNetworkIpamConfig
from .types import EngineSetting
from .types import Endpoint
from .types import EndpointSpecLoadBalancer
from .types import EndpointSpecPrivateNetwork
from .types import ReadReplicaEndpointSpecDirectAccess
from .types import ReadReplicaEndpointSpecPrivateNetwork
from .types import EngineVersion
from .types import BackupSchedule
from .types import InstanceSetting
from .types import LogsPolicy
from .types import Maintenance
from .types import ReadReplica
from .types import UpgradableVersion
from .types import Volume
from .types import NodeTypeVolumeConstraintSizes
from .types import NodeTypeVolumeType
from .types import SnapshotVolumeType
from .types import ACLRuleRequest
from .types import ACLRule
from .types import EndpointSpec
from .types import ReadReplicaEndpointSpec
from .types import DatabaseEngine
from .types import Database
from .types import ListInstanceLogsDetailsResponseInstanceLogDetail
from .types import InstanceLog
from .types import Instance
from .types import NodeType
from .types import Privilege
from .types import Snapshot
from .types import User
from .types import UpgradeInstanceRequestMajorUpgradeWorkflow
from .types import AddInstanceACLRulesRequest
from .types import AddInstanceACLRulesResponse
from .types import AddInstanceSettingsRequest
from .types import AddInstanceSettingsResponse
from .types import ApplyInstanceMaintenanceRequest
from .types import CloneInstanceRequest
from .types import CreateDatabaseRequest
from .types import CreateEndpointRequest
from .types import CreateInstanceFromSnapshotRequest
from .types import CreateInstanceRequest
from .types import CreateReadReplicaEndpointRequest
from .types import CreateReadReplicaRequest
from .types import CreateSnapshotRequest
from .types import CreateUserRequest
from .types import DeleteDatabaseRequest
from .types import DeleteEndpointRequest
from .types import DeleteInstanceACLRulesRequest
from .types import DeleteInstanceACLRulesResponse
from .types import DeleteInstanceRequest
from .types import DeleteInstanceSettingsRequest
from .types import DeleteInstanceSettingsResponse
from .types import DeleteReadReplicaRequest
from .types import DeleteSnapshotRequest
from .types import DeleteUserRequest
from .types import GetEndpointRequest
from .types import GetInstanceCertificateRequest
from .types import GetInstanceLogRequest
from .types import GetInstanceMetricsRequest
from .types import GetInstanceRequest
from .types import GetReadReplicaRequest
from .types import GetSnapshotRequest
from .types import InstanceMetrics
from .types import ListDatabaseEnginesRequest
from .types import ListDatabaseEnginesResponse
from .types import ListDatabasesRequest
from .types import ListDatabasesResponse
from .types import ListInstanceACLRulesRequest
from .types import ListInstanceACLRulesResponse
from .types import ListInstanceLogsDetailsRequest
from .types import ListInstanceLogsDetailsResponse
from .types import ListInstanceLogsRequest
from .types import ListInstanceLogsResponse
from .types import ListInstancesRequest
from .types import ListInstancesResponse
from .types import ListNodeTypesRequest
from .types import ListNodeTypesResponse
from .types import ListPrivilegesRequest
from .types import ListPrivilegesResponse
from .types import ListSnapshotsRequest
from .types import ListSnapshotsResponse
from .types import ListUsersRequest
from .types import ListUsersResponse
from .types import MigrateEndpointRequest
from .types import PromoteReadReplicaRequest
from .types import PurgeInstanceLogsRequest
from .types import RenewInstanceCertificateRequest
from .types import ResetReadReplicaRequest
from .types import RestartInstanceRequest
from .types import SetInstanceACLRulesRequest
from .types import SetInstanceACLRulesResponse
from .types import SetInstanceSettingsRequest
from .types import SetInstanceSettingsResponse
from .types import SetPrivilegeRequest
from .types import UpdateInstanceRequest
from .types import UpdateSnapshotRequest
from .types import UpdateUserRequest
from .types import UpgradeInstanceRequest
from .api import DocumentDbV1Beta1API

__all__ = [
    "ACLRuleAction",
    "ACLRuleDirection",
    "ACLRuleProtocol",
    "EngineSettingPropertyType",
    "InstanceLogStatus",
    "INSTANCE_LOG_TRANSIENT_STATUSES",
    "InstanceStatus",
    "INSTANCE_TRANSIENT_STATUSES",
    "ListDatabasesRequestOrderBy",
    "ListInstanceLogsRequestOrderBy",
    "ListInstancesRequestOrderBy",
    "ListPrivilegesRequestOrderBy",
    "ListSnapshotsRequestOrderBy",
    "ListUsersRequestOrderBy",
    "MaintenanceStatus",
    "MAINTENANCE_TRANSIENT_STATUSES",
    "NodeTypeGeneration",
    "NodeTypeStock",
    "Permission",
    "ReadReplicaStatus",
    "READ_REPLICA_TRANSIENT_STATUSES",
    "SnapshotStatus",
    "SNAPSHOT_TRANSIENT_STATUSES",
    "StorageClass",
    "VolumeType",
    "EndpointDirectAccessDetails",
    "EndpointLoadBalancerDetails",
    "EndpointPrivateNetworkDetails",
    "EndpointSpecPrivateNetworkIpamConfig",
    "ReadReplicaEndpointSpecPrivateNetworkIpamConfig",
    "EngineSetting",
    "Endpoint",
    "EndpointSpecLoadBalancer",
    "EndpointSpecPrivateNetwork",
    "ReadReplicaEndpointSpecDirectAccess",
    "ReadReplicaEndpointSpecPrivateNetwork",
    "EngineVersion",
    "BackupSchedule",
    "InstanceSetting",
    "LogsPolicy",
    "Maintenance",
    "ReadReplica",
    "UpgradableVersion",
    "Volume",
    "NodeTypeVolumeConstraintSizes",
    "NodeTypeVolumeType",
    "SnapshotVolumeType",
    "ACLRuleRequest",
    "ACLRule",
    "EndpointSpec",
    "ReadReplicaEndpointSpec",
    "DatabaseEngine",
    "Database",
    "ListInstanceLogsDetailsResponseInstanceLogDetail",
    "InstanceLog",
    "Instance",
    "NodeType",
    "Privilege",
    "Snapshot",
    "User",
    "UpgradeInstanceRequestMajorUpgradeWorkflow",
    "AddInstanceACLRulesRequest",
    "AddInstanceACLRulesResponse",
    "AddInstanceSettingsRequest",
    "AddInstanceSettingsResponse",
    "ApplyInstanceMaintenanceRequest",
    "CloneInstanceRequest",
    "CreateDatabaseRequest",
    "CreateEndpointRequest",
    "CreateInstanceFromSnapshotRequest",
    "CreateInstanceRequest",
    "CreateReadReplicaEndpointRequest",
    "CreateReadReplicaRequest",
    "CreateSnapshotRequest",
    "CreateUserRequest",
    "DeleteDatabaseRequest",
    "DeleteEndpointRequest",
    "DeleteInstanceACLRulesRequest",
    "DeleteInstanceACLRulesResponse",
    "DeleteInstanceRequest",
    "DeleteInstanceSettingsRequest",
    "DeleteInstanceSettingsResponse",
    "DeleteReadReplicaRequest",
    "DeleteSnapshotRequest",
    "DeleteUserRequest",
    "GetEndpointRequest",
    "GetInstanceCertificateRequest",
    "GetInstanceLogRequest",
    "GetInstanceMetricsRequest",
    "GetInstanceRequest",
    "GetReadReplicaRequest",
    "GetSnapshotRequest",
    "InstanceMetrics",
    "ListDatabaseEnginesRequest",
    "ListDatabaseEnginesResponse",
    "ListDatabasesRequest",
    "ListDatabasesResponse",
    "ListInstanceACLRulesRequest",
    "ListInstanceACLRulesResponse",
    "ListInstanceLogsDetailsRequest",
    "ListInstanceLogsDetailsResponse",
    "ListInstanceLogsRequest",
    "ListInstanceLogsResponse",
    "ListInstancesRequest",
    "ListInstancesResponse",
    "ListNodeTypesRequest",
    "ListNodeTypesResponse",
    "ListPrivilegesRequest",
    "ListPrivilegesResponse",
    "ListSnapshotsRequest",
    "ListSnapshotsResponse",
    "ListUsersRequest",
    "ListUsersResponse",
    "MigrateEndpointRequest",
    "PromoteReadReplicaRequest",
    "PurgeInstanceLogsRequest",
    "RenewInstanceCertificateRequest",
    "ResetReadReplicaRequest",
    "RestartInstanceRequest",
    "SetInstanceACLRulesRequest",
    "SetInstanceACLRulesResponse",
    "SetInstanceSettingsRequest",
    "SetInstanceSettingsResponse",
    "SetPrivilegeRequest",
    "UpdateInstanceRequest",
    "UpdateSnapshotRequest",
    "UpdateUserRequest",
    "UpgradeInstanceRequest",
    "DocumentDbV1Beta1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.utils import (
    StrEnumMeta,
)


class BearerType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_BEARER_TYPE = "unknown_bearer_type"
    USER = "user"
    APPLICATION = "application"

    def __str__(self) -> str:
        return str(self.value)


class ListAPIKeysRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    EXPIRES_AT_ASC = "expires_at_asc"
    EXPIRES_AT_DESC = "expires_at_desc"
    ACCESS_KEY_ASC = "access_key_asc"
    ACCESS_KEY_DESC = "access_key_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListApplicationsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListGroupsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListJWTsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListLogsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPermissionSetsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPoliciesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    POLICY_NAME_ASC = "policy_name_asc"
    POLICY_NAME_DESC = "policy_name_desc"
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListQuotaRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListSSHKeysRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListUsersRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    EMAIL_ASC = "email_asc"
    EMAIL_DESC = "email_desc"
    LAST_LOGIN_ASC = "last_login_asc"
    LAST_LOGIN_DESC = "last_login_desc"

    def __str__(self) -> str:
        return str(self.value)


class LogAction(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_ACTION = "unknown_action"
    CREATED = "created"
    UPDATED = "updated"
    DELETED = "deleted"

    def __str__(self) -> str:
        return str(self.value)


class LogResourceType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_RESOURCE_TYPE = "unknown_resource_type"
    API_KEY = "api_key"
    USER = "user"
    APPLICATION = "application"
    GROUP = "group"
    POLICY = "policy"

    def __str__(self) -> str:
        return str(self.value)


class PermissionSetScopeType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_SCOPE_TYPE = "unknown_scope_type"
    PROJECTS = "projects"
    ORGANIZATION = "organization"
    ACCOUNT_ROOT_USER = "account_root_user"

    def __str__(self) -> str:
        return str(self.value)


class UserStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATUS = "unknown_status"
    INVITATION_PENDING = "invitation_pending"
    ACTIVATED = "activated"

    def __str__(self) -> str:
        return str(self.value)


class UserType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_TYPE = "unknown_type"
    GUEST = "guest"
    OWNER = "owner"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class RuleSpecs:
    permission_set_names: Optional[List[str]]
    """
    Names of permission sets bound to the rule.
    """

    project_ids: Optional[List[str]]

    organization_id: Optional[str]


@dataclass
class JWT:
    jti: str
    """
    JWT ID.
    """

    issuer_id: str
    """
    ID of the user who issued the JWT.
    """

    audience_id: str
    """
    ID of the user targeted by the JWT.
    """

    ip: str
    """
    IP address used during the creation of the JWT.
    """

    user_agent: str
    """
    User-agent used during the creation of the JWT.
    """

    created_at: Optional[datetime]
    """
    Creation date of the JWT.
    """

    updated_at: Optional[datetime]
    """
    Last update date of the JWT.
    """

    expires_at: Optional[datetime]
    """
    Expiration date of the JWT.
    """


@dataclass
class APIKey:
    access_key: str
    """
    Access key of the API key.
    """

    description: str
    """
    Description of API key.
    """

    default_project_id: str
    """
    Default Project ID specified for this API key.
    """

    editable: bool
    """
    Defines whether or not the API key is editable.
    """

    creation_ip: str
    """
    IP address of the device that created the API key.
    """

    secret_key: Optional[str]
    """
    Secret key of the API Key.
    """

    created_at: Optional[datetime]
    """
    Date and time of API key creation.
    """

    updated_at: Optional[datetime]
    """
    Date and time of last API key update.
    """

    expires_at: Optional[datetime]
    """
    Date and time of API key expiration.
    """

    application_id: Optional[str]

    user_id: Optional[str]


@dataclass
class Application:
    id: str
    """
    ID of the application.
    """

    name: str
    """
    Name of the application.
    """

    description: str
    """
    Description of the application.
    """

    organization_id: str
    """
    ID of the Organization.
    """

    editable: bool
    """
    Defines whether or not the application is editable.
    """

    nb_api_keys: int
    """
    Number of API keys attributed to the application.
    """

    tags: List[str]
    """
    Tags associated with the user.
    """

    created_at: Optional[datetime]
    """
    Date and time application was created.
    """

    updated_at: Optional[datetime]
    """
    Date and time of last application update.
    """


@dataclass
class Group:
    id: str
    """
    ID of the group.
    """

    organization_id: str
    """
    ID of Organization linked to the group.
    """

    name: str
    """
    Name of the group.
    """

    description: str
    """
    Description of the group.
    """

    user_ids: List[str]
    """
    IDs of users attached to this group.
    """

    application_ids: List[str]
    """
    IDs of applications attached to this group.
    """

    tags: List[str]
    """
    Tags associated to the group.
    """

    created_at: Optional[datetime]
    """
    Date and time of group creation.
    """

    updated_at: Optional[datetime]
    """
    Date and time of last group update.
    """


@dataclass
class Log:
    id: str
    """
    Log ID.
    """

    ip: str
    """
    IP address of the HTTP request linked to the log.
    """

    user_agent: str
    """
    User-Agent of the HTTP request linked to the log.
    """

    action: LogAction
    """
    Action linked to the log.
    """

    bearer_id: str
    """
    ID of the principal at the origin of the log.
    """

    organization_id: str
    """
    ID of Organization linked to the log.
    """

    resource_type: LogResourceType
    """
    Type of the resource linked to the log.
    """

    resource_id: str
    """
    ID of the resource linked  to the log.
    """

    created_at: Optional[datetime]
    """
    Creation date of the log.
    """


@dataclass
class PermissionSet:
    id: str
    """
    Id of the permission set.
    """

    name: str
    """
    Name of the permission set.
    """

    scope_type: PermissionSetScopeType
    """
    Scope of the permission set.
    """

    description: str
    """
    Description of the permission set.
    """

    categories: Optional[List[str]]
    """
    Categories of the permission set.
    """


@dataclass
class Policy:
    id: str
    """
    Id of the policy.
    """

    name: str
    """
    Name of the policy.
    """

    description: str
    """
    Description of the policy.
    """

    organization_id: str
    """
    Organization ID of the policy.
    """

    editable: bool
    """
    Defines whether or not a policy is editable.
    """

    nb_rules: int
    """
    Number of rules of the policy.
    """

    nb_scopes: int
    """
    Number of policy scopes.
    """

    nb_permission_sets: int
    """
    Number of permission sets of the policy.
    """

    tags: List[str]
    """
    Tags associated with the policy.
    """

    created_at: Optional[datetime]
    """
    Date and time of policy creation.
    """

    updated_at: Optional[datetime]
    """
    Date and time of last policy update.
    """

    user_id: Optional[str]

    group_id: Optional[str]

    application_id: Optional[str]

    no_principal: Optional[bool]


@dataclass
class Quotum:
    name: str
    """
    Name of the quota.
    """

    pretty_name: str
    """
    A human-readable name for the quota.
    """

    unit: str
    """
    The unit in which the quota is expressed.
    """

    description: str
    """
    Details about the quota.
    """

    limit: Optional[int]

    unlimited: Optional[bool]


@dataclass
class Rule:
    id: str
    """
    Id of rule.
    """

    permission_sets_scope_type: PermissionSetScopeType
    """
    Permission_set_names have the same scope_type.
    """

    permission_set_names: Optional[List[str]]
    """
    Names of permission sets bound to the rule.
    """

    project_ids: Optional[List[str]]

    organization_id: Optional[str]

    account_root_user_id: Optional[str]


@dataclass
class SSHKey:
    id: str
    """
    ID of SSH key.
    """

    name: str
    """
    Name of SSH key.
    """

    public_key: str
    """
    Public key of SSH key.
    """

    fingerprint: str
    """
    Fingerprint of the SSH key.
    """

    organization_id: str
    """
    ID of Organization linked to the SSH key.
    """

    project_id: str
    """
    ID of Project linked to the SSH key.
    """

    disabled: bool
    """
    SSH key status.
    """

    created_at: Optional[datetime]
    """
    Creation date of SSH key.
    """

    updated_at: Optional[datetime]
    """
    Last update date of SSH key.
    """


@dataclass
class User:
    id: str
    """
    ID of user.
    """

    email: str
    """
    Email of user.
    """

    organization_id: str
    """
    ID of the Organization.
    """

    deletable: bool
    """
    Deletion status of user. Owners cannot be deleted.
    """

    type_: UserType
    """
    Type of user.
    """

    status: UserStatus
    """
    Status of user invitation.
    """

    created_at: Optional[datetime]
    """
    Date user was created.
    """

    mfa: bool
    """
    Defines whether MFA is enabled.
    """

    account_root_user_id: str
    """
    ID of the account root user associated with the user.
    """

    tags: List[str]
    """
    Tags associated with the user.
    """

    updated_at: Optional[datetime]
    """
    Date of last user update.
    """

    last_login_at: Optional[datetime]
    """
    Date of the last login.
    """

    two_factor_enabled: Optional[bool]
    """
    Deprecated, use "mfa" instead.
    """


@dataclass
class AddGroupMemberRequest:
    group_id: str
    """
    ID of the group.
    """

    user_id: Optional[str]

    application_id: Optional[str]


@dataclass
class AddGroupMembersRequest:
    group_id: str
    """
    ID of the group.
    """

    user_ids: Optional[List[str]]
    """
    IDs of the users to add.
    """

    application_ids: Optional[List[str]]
    """
    IDs of the applications to add.
    """


@dataclass
class ClonePolicyRequest:
    policy_id: str


@dataclass
class CreateAPIKeyRequest:
    description: str
    """
    Description of the API key (max length is 200 characters).
    """

    expires_at: Optional[datetime]
    """
    Expiration date of the API key.
    """

    default_project_id: Optional[str]
    """
    Default Project ID to use with Object Storage.
    """

    application_id: Optional[str]

    user_id: Optional[str]


@dataclass
class CreateApplicationRequest:
    description: str
    """
    Description of the application (max length is 200 characters).
    """

    name: Optional[str]
    """
    Name of the application to create (max length is 64 characters).
    """

    organization_id: Optional[str]
    """
    ID of the Organization.
    """

    tags: Optional[List[str]]
    """
    Tags associated with the application (maximum of 10 tags).
    """


@dataclass
class CreateGroupRequest:
    description: str
    """
    Description of the group to create (max length is 200 chars).
    """

    organization_id: Optional[str]
    """
    ID of Organization linked to the group.
    """

    name: Optional[str]
    """
    Name of the group to create (max length is 64 chars). MUST be unique inside an Organization.
    """

    tags: Optional[List[str]]
    """
    Tags associated with the group (maximum of 10 tags).
    """


@dataclass
class CreateJWTRequest:
    user_id: str
    """
    ID of the user the JWT will be created for.
    """

    referrer: str
    """
    Referrer of the JWT.
    """


@dataclass
class CreatePolicyRequest:
    description: str
    """
    Description of the policy to create (max length is 200 characters).
    """

    name: Optional[str]
    """
    Name of the policy to create (max length is 64 characters).
    """

    organization_id: Optional[str]
    """
    ID of the Organization.
    """

    rules: Optional[List[RuleSpecs]]
    """
    Rules of the policy to create.
    """

    tags: Optional[List[str]]
    """
    Tags associated with the policy (maximum of 10 tags).
    """

    user_id: Optional[str]

    group_id: Optional[str]

    application_id: Optional[str]

    no_principal: Optional[bool]


@dataclass
class CreateSSHKeyRequest:
    public_key: str
    """
    SSH public key. Currently only the ssh-rsa, ssh-dss (DSA), ssh-ed25519 and ecdsa keys with NIST curves are supported. Max length is 65000.
    """

    name: Optional[str]
    """
    Name of the SSH key. Max length is 1000.
    """

    project_id: Optional[str]
    """
    Project the resource is attributed to.
    """


@dataclass
class CreateUserRequest:
    email: str
    """
    Email of the user.
    """

    organization_id: Optional[str]
    """
    ID of the Organization.
    """

    tags: Optional[List[str]]
    """
    Tags associated with the user.
    """


@dataclass
class DeleteAPIKeyRequest:
    access_key: str
    """
    Access key to delete.
    """


@dataclass
class DeleteApplicationRequest:
    application_id: str
    """
    ID of the application to delete.
    """


@dataclass
class DeleteGroupRequest:
    group_id: str
    """
    ID of the group to delete.
    """


@dataclass
class DeleteJWTRequest:
    jti: str
    """
    JWT ID of the JWT to delete.
    """


@dataclass
class DeletePolicyRequest:
    policy_id: str
    """
    Id of policy to delete.
    """


@dataclass
class DeleteSSHKeyRequest:
    ssh_key_id: str


@dataclass
class DeleteUserRequest:
    user_id: str
    """
    ID of the user to delete.
    """


@dataclass
class EncodedJWT:
    token: str
    """
    The encoded token of the renewed JWT.
    """

    renew_token: str
    """
    The encoded renew token. This token is necessary to renew the JWT.
    """

    jwt: Optional[JWT]
    """
    The renewed JWT.
    """


@dataclass
class GetAPIKeyRequest:
    access_key: str
    """
    Access key to search for.
    """


@dataclass
class GetApplicationRequest:
    application_id: str
    """
    ID of the application to find.
    """


@dataclass
class GetGroupRequest:
    group_id: str
    """
    ID of the group.
    """


@dataclass
class GetJWTRequest:
    jti: str
    """
    JWT ID of the JWT to get.
    """


@dataclass
class GetLogRequest:
    log_id: str
    """
    ID of the log.
    """


@dataclass
class GetPolicyRequest:
    policy_id: str
    """
    Id of policy to search.
    """


@dataclass
class GetQuotumRequest:
    quotum_name: str
    """
    Name of the quota to get.
    """

    organization_id: Optional[str]
    """
    ID of the Organization.
    """


@dataclass
class GetSSHKeyRequest:
    ssh_key_id: str
    """
    ID of the SSH key.
    """


@dataclass
class GetUserRequest:
    user_id: str
    """
    ID of the user to find.
    """


@dataclass
class ListAPIKeysRequest:
    order_by: Optional[ListAPIKeysRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page: Optional[int]
    """
    Page number. Value must be greater or equal to 1.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    organization_id: Optional[str]
    """
    ID of Organization.
    """

    editable: Optional[bool]
    """
    Defines whether to filter out editable API keys or not.
    """

    expired: Optional[bool]
    """
    Defines whether to filter out expired API keys or not.
    """

    access_key: Optional[str]
    """
    Filter by access key (deprecated in favor of `access_keys`).
    """

    description: Optional[str]
    """
    Filter by description.
    """

    bearer_id: Optional[str]
    """
    Filter by bearer ID.
    """

    bearer_type: Optional[BearerType]
    """
    Filter by type of bearer.
    """

    access_keys: Optional[List[str]]
    """
    Filter by a list of access keys.
    """

    application_id: Optional[str]

    user_id: Optional[str]


@dataclass
class ListAPIKeysResponse:
    api_keys: List[APIKey]
    """
    List of API keys.
    """

    total_count: int
    """
    Total count of API Keys.
    """


@dataclass
class ListApplicationsRequest:
    order_by: Optional[ListApplicationsRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater than 1.
    """

    name: Optional[str]
    """
    Name of the application to filter.
    """

    organization_id: Optional[str]
    """
    ID of the Organization to filter.
    """

    editable: Optional[bool]
    """
    Defines whether to filter out editable applications or not.
    """

    application_ids: Optional[List[str]]
    """
    Filter by list of IDs.
    """

    tag: Optional[str]
    """
    Filter by tags containing a given string.
    """


@dataclass
class ListApplicationsResponse:
    applications: List[Application]
    """
    List of applications.
    """

    total_count: int
    """
    Total count of applications.
    """


@dataclass
class ListGroupsRequest:
    order_by: Optional[ListGroupsRequestOrderBy]
    """
    Sort order of groups.
    """

    page: Optional[int]
    """
    Requested page number. Value must be greater or equal to 1.
    """

    page_size: Optional[int]
    """
    Number of items per page. Value must be between 1 and 100.
    """

    organization_id: Optional[str]
    """
    Filter by Organization ID.
    """

    name: Optional[str]
    """
    Name of group to find.
    """

    application_ids: Optional[List[str]]
    """
    Filter by a list of application IDs.
    """

    user_ids: Optional[List[str]]
    """
    Filter by a list of user IDs.
    """

    group_ids: Optional[List[str]]
    """
    Filter by a list of group IDs.
    """

    tag: Optional[str]
    """
    Filter by tags containing a given string.
    """


@dataclass
class ListGroupsResponse:
    groups: List[Group]
    """
    List of groups.
    """

    total_count: int
    """
    Total count of groups.
    """


@dataclass
class ListJWTsRequest:
    order_by: Optional[ListJWTsRequestOrderBy]
    """
    Criteria for sorting results.
    """

    audience_id: Optional[str]
    """
    ID of the user to search.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater to 1.
    """

    expired: Optional[bool]
    """
    Filter out expired JWTs or not.
    """


@dataclass
class ListJWTsResponse:
    jwts: List[JWT]

    total_count: int


@dataclass
class ListLogsRequest:
    order_by: Optional[ListLogsRequestOrderBy]
    """
    Criteria for sorting results.
    """

    organization_id: Optional[str]
    """
    Filter by Organization ID.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater to 1.
    """

    created_after: Optional[datetime]
    """
    Defined whether or not to filter out logs created after this timestamp.
    """

    created_before: Optional[datetime]
    """
    Defined whether or not to filter out logs created before this timestamp.
    """

    action: Optional[LogAction]
    """
    Defined whether or not to filter out by a specific action.
    """

    resource_type: Optional[LogResourceType]
    """
    Defined whether or not to filter out by a specific type of resource.
    """

    search: Optional[str]
    """
    Defined whether or not to filter out log by bearer ID or resource ID.
    """


@dataclass
class ListLogsResponse:
    logs: List[Log]
    """
    List of logs.
    """

    total_count: int
    """
    Total count of logs.
    """


@dataclass
class ListPermissionSetsRequest:
    order_by: Optional[ListPermissionSetsRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater than 1.
    """

    organization_id: Optional[str]
    """
    Filter by Organization ID.
    """


@dataclass
class ListPermissionSetsResponse:
    permission_sets: List[PermissionSet]
    """
    List of permission sets.
    """

    total_count: int
    """
    Total count of permission sets.
    """


@dataclass
class ListPoliciesRequest:
    order_by: Optional[ListPoliciesRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater than 1.
    """

    organization_id: Optional[str]
    """
    ID of the Organization to filter.
    """

    editable: Optional[bool]
    """
    Defines whether or not filter out editable policies.
    """

    user_ids: Optional[List[str]]
    """
    Defines whether or not to filter by list of user IDs.
    """

    group_ids: Optional[List[str]]
    """
    Defines whether or not to filter by list of group IDs.
    """

    application_ids: Optional[List[str]]
    """
    Filter by a list of application IDs.
    """

    no_principal: Optional[bool]
    """
    Defines whether or not the policy is attributed to a principal.
    """

    policy_name: Optional[str]
    """
    Name of the policy to fetch.
    """

    tag: Optional[str]
    """
    Filter by tags containing a given string.
    """

    policy_ids: Optional[List[str]]
    """
    Filter by a list of IDs.
    """


@dataclass
class ListPoliciesResponse:
    policies: List[Policy]
    """
    List of policies.
    """

    total_count: int
    """
    Total count of policies.
    """


@dataclass
class ListQuotaRequest:
    order_by: Optional[ListQuotaRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater than 1.
    """

    organization_id: Optional[str]
    """
    Filter by Organization ID.
    """

    quotum_names: Optional[List[str]]
    """
    List of quotum names to filter from.
    """


@dataclass
class ListQuotaResponse:
    quota: List[Quotum]
    """
    List of quota.
    """

    total_count: int
    """
    Total count of quota.
    """


@dataclass
class ListRulesRequest:
    policy_id: str
    """
    Id of policy to search.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater than 1.
    """


@dataclass
class ListRulesResponse:
    rules: List[Rule]
    """
    Rules of the policy.
    """

    total_count: int
    """
    Total count of rules.
    """


@dataclass
class ListSSHKeysRequest:
    order_by: Optional[ListSSHKeysRequestOrderBy]
    """
    Sort order of the SSH keys.
    """

    page: Optional[int]
    """
    Requested page number. Value must be greater or equal to 1.
    """

    page_size: Optional[int]
    """
    Number of items per page. Value must be between 1 and 100.
    """

    organization_id: Optional[str]
    """
    Filter by Organization ID.
    """

    name: Optional[str]
    """
    Name of group to find.
    """

    project_id: Optional[str]
    """
    Filter by Project ID.
    """

    disabled: Optional[bool]
    """
    Defines whether to include disabled SSH keys or not.
    """


@dataclass
class ListSSHKeysResponse:
    ssh_keys: List[SSHKey]
    """
    List of SSH keys.
    """

    total_count: int
    """
    Total count of SSH keys.
    """


@dataclass
class ListUsersRequest:
    order_by: Optional[ListUsersRequestOrderBy]
    """
    Criteria for sorting results.
    """

    page_size: Optional[int]
    """
    Number of results per page. Value must be between 1 and 100.
    """

    page: Optional[int]
    """
    Page number. Value must be greater or equal to 1.
    """

    organization_id: Optional[str]
    """
    ID of the Organization to filter.
    """

    user_ids: Optional[List[str]]
    """
    Filter by list of IDs.
    """

    mfa: Optional[bool]
    """
    Filter by MFA status.
    """

    tag: Optional[str]
    """
    Filter by tags containing a given string.
    """


@dataclass
class ListUsersResponse:
    users: List[User]
    """
    List of users.
    """

    total_count: int
    """
    Total count of users.
    """


@dataclass
class RemoveGroupMemberRequest:
    group_id: str
    """
    ID of the group.
    """

    user_id: Optional[str]

    application_id: Optional[str]


@dataclass
class SetGroupMembersRequest:
    group_id: str

    user_ids: List[str]

    application_ids: List[str]


@dataclass
class SetRulesRequest:
    policy_id: str
    """
    Id of policy to update.
    """

    rules: List[RuleSpecs]
    """
    Rules of the policy to set.
    """


@dataclass
class SetRulesResponse:
    rules: List[Rule]
    """
    Rules of the policy.
    """


@dataclass
class UpdateAPIKeyRequest:
    access_key: str
    """
    Access key to update.
    """

    default_project_id: Optional[str]
    """
    New default Project ID to set.
    """

    description: Optional[str]
    """
    New description to update.
    """


@dataclass
class UpdateApplicationRequest:
    application_id: str
    """
    ID of the application to update.
    """

    name: Optional[str]
    """
    New name for the application (max length is 64 chars).
    """

    description: Optional[str]
    """
    New description for the application (max length is 200 chars).
    """

    tags: Optional[List[str]]
    """
    New tags for the application (maximum of 10 tags).
    """


@dataclass
class UpdateGroupRequest:
    group_id: str
    """
    ID of the group to update.
    """

    name: Optional[str]
    """
    New name for the group (max length is 64 chars). MUST be unique inside an Organization.
    """

    description: Optional[str]
    """
    New description for the group (max length is 200 chars).
    """

    tags: Optional[List[str]]
    """
    New tags for the group (maximum of 10 tags).
    """


@dataclass
class UpdatePolicyRequest:
    policy_id: str
    """
    Id of policy to update.
    """

    name: Optional[str]
    """
    New name for the policy (max length is 64 characters).
    """

    description: Optional[str]
    """
    New description of policy (max length is 200 characters).
    """

    tags: Optional[List[str]]
    """
    New tags for the policy (maximum of 10 tags).
    """

    user_id: Optional[str]

    group_id: Optional[str]

    application_id: Optional[str]

    no_principal: Optional[bool]


@dataclass
class UpdateSSHKeyRequest:
    ssh_key_id: str

    name: Optional[str]
    """
    Name of the SSH key. Max length is 1000.
    """

    disabled: Optional[bool]
    """
    Enable or disable the SSH key.
    """


@dataclass
class UpdateUserRequest:
    user_id: str
    """
    ID of the user to update.
    """

    tags: Optional[List[str]]
    """
    New tags for the user (maximum of 10 tags).
    """



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ApplicationType
from .types import JobStatus
from .content import JOB_TRANSIENT_STATUSES
from .types import ListApplicationsRequestOrderBy
from .types import ListJobResultsRequestOrderBy
from .types import ListJobsRequestOrderBy
from .types import ListPlatformsRequestOrderBy
from .types import ListProcessResultsRequestOrderBy
from .types import ListProcessesRequestOrderBy
from .types import ListSessionACLsRequestOrderBy
from .types import ListSessionsRequestOrderBy
from .types import PlatformTechnology
from .types import PlatformType
from .types import ProcessStatus
from .content import PROCESS_TRANSIENT_STATUSES
from .types import SessionAccess
from .types import SessionOriginType
from .types import SessionStatus
from .content import SESSION_TRANSIENT_STATUSES
from .types import JobCircuit
from .types import Application
from .types import JobResult
from .types import Job
from .types import Platform
from .types import ProcessResult
from .types import Process
from .types import Session
from .types import CancelJobRequest
from .types import CancelProcessRequest
from .types import CreateJobRequest
from .types import CreateProcessRequest
from .types import CreateSessionRequest
from .types import DeleteJobRequest
from .types import DeleteProcessRequest
from .types import DeleteSessionRequest
from .types import GetApplicationRequest
from .types import GetJobCircuitRequest
from .types import GetJobRequest
from .types import GetPlatformRequest
from .types import GetProcessRequest
from .types import GetSessionRequest
from .types import ListApplicationsRequest
from .types import ListApplicationsResponse
from .types import ListJobResultsRequest
from .types import ListJobResultsResponse
from .types import ListJobsRequest
from .types import ListJobsResponse
from .types import ListPlatformsRequest
from .types import ListPlatformsResponse
from .types import ListProcessResultsRequest
from .types import ListProcessResultsResponse
from .types import ListProcessesRequest
from .types import ListProcessesResponse
from .types import ListSessionACLsRequest
from .types import ListSessionACLsResponse
from .types import ListSessionsRequest
from .types import ListSessionsResponse
from .types import TerminateSessionRequest
from .types import UpdateJobRequest
from .types import UpdateProcessRequest
from .types import UpdateSessionRequest
from .api import QaasV1Alpha1API

__all__ = [
    "ApplicationType",
    "JobStatus",
    "JOB_TRANSIENT_STATUSES",
    "ListApplicationsRequestOrderBy",
    "ListJobResultsRequestOrderBy",
    "ListJobsRequestOrderBy",
    "ListPlatformsRequestOrderBy",
    "ListProcessResultsRequestOrderBy",
    "ListProcessesRequestOrderBy",
    "ListSessionACLsRequestOrderBy",
    "ListSessionsRequestOrderBy",
    "PlatformTechnology",
    "PlatformType",
    "ProcessStatus",
    "PROCESS_TRANSIENT_STATUSES",
    "SessionAccess",
    "SessionOriginType",
    "SessionStatus",
    "SESSION_TRANSIENT_STATUSES",
    "JobCircuit",
    "Application",
    "JobResult",
    "Job",
    "Platform",
    "ProcessResult",
    "Process",
    "Session",
    "CancelJobRequest",
    "CancelProcessRequest",
    "CreateJobRequest",
    "CreateProcessRequest",
    "CreateSessionRequest",
    "DeleteJobRequest",
    "DeleteProcessRequest",
    "DeleteSessionRequest",
    "GetApplicationRequest",
    "GetJobCircuitRequest",
    "GetJobRequest",
    "GetPlatformRequest",
    "GetProcessRequest",
    "GetSessionRequest",
    "ListApplicationsRequest",
    "ListApplicationsResponse",
    "ListJobResultsRequest",
    "ListJobResultsResponse",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListPlatformsRequest",
    "ListPlatformsResponse",
    "ListProcessResultsRequest",
    "ListProcessResultsResponse",
    "ListProcessesRequest",
    "ListProcessesResponse",
    "ListSessionACLsRequest",
    "ListSessionACLsResponse",
    "ListSessionsRequest",
    "ListSessionsResponse",
    "TerminateSessionRequest",
    "UpdateJobRequest",
    "UpdateProcessRequest",
    "UpdateSessionRequest",
    "QaasV1Alpha1API",
]
